diff libpurple/ft.h @ 30435:d487a2adc3a6

merge of '86d9ff7ca5af691007b1e85ef39959fa13e7d996' and 'd0cbcbb1a25505fd8801dd556c1ec42e98414c9a'
author Elliott Sales de Andrade <qulogic@pidgin.im>
date Mon, 23 Aug 2010 05:22:11 +0000
parents 1cdae196aac8
children 44f53d3fc54f
line wrap: on
line diff
--- a/libpurple/ft.h	Mon Aug 23 01:18:12 2010 +0000
+++ b/libpurple/ft.h	Mon Aug 23 05:22:11 2010 +0000
@@ -58,8 +58,8 @@
 	PURPLE_XFER_STATUS_ACCEPTED,      /**< Receive accepted, but destination file not selected yet */
 	PURPLE_XFER_STATUS_STARTED,       /**< purple_xfer_start has been called. */
 	PURPLE_XFER_STATUS_DONE,          /**< The xfer completed successfully. */
-	PURPLE_XFER_STATUS_CANCEL_LOCAL,  /**< The xfer was canceled by us. */
-	PURPLE_XFER_STATUS_CANCEL_REMOTE  /**< The xfer was canceled by the other end, or we couldn't connect. */
+	PURPLE_XFER_STATUS_CANCEL_LOCAL,  /**< The xfer was cancelled by us. */
+	PURPLE_XFER_STATUS_CANCEL_REMOTE  /**< The xfer was cancelled by the other end, or we couldn't connect. */
 } PurpleXferStatusType;
 
 /**
@@ -304,11 +304,12 @@
 PurpleXferStatusType purple_xfer_get_status(const PurpleXfer *xfer);
 
 /**
  * Returns true if the file transfer was canceled.
  *
  * @param xfer The file transfer.
  *
- * @return Whether or not the transfer was canceled.
+ * @return Whether or not the transfer was cancelled.
+ * FIXME: This should be renamed using cancelled for 3.0.0.
  */
 gboolean purple_xfer_is_canceled(const PurpleXfer *xfer);
@@ -304,11 +304,12 @@
 
 /**
- * Returns true if the file transfer was canceled.
+ * Returns true if the file transfer was cancelled.
  *
  * @param xfer The file transfer.